from .api_wrapper import TraceMoe

__all__ = ("TraceMoe",)


__version__ = '2.0.0'
__api_version__ = '1.0.0'
